grib2io.tables.section4_discipline10 API documentation

# grib2io.tables.section4_discipline10

View Source

      1table_4_2_10_0  = {
      2'0':['Wave Spectra (1)','-','WVSP1'],
      3'1':['Wave Spectra (2)','-','WVSP2'],
      4'2':['Wave Spectra (3)','-','WVSP3'],
      5'3':['Significant Height of Combined Wind Waves and Swell','m','HTSGW'],
      6'4':['Direction of Wind Waves','degree true','WVDIR'],
      7'5':['Significant Height of Wind Waves','m','WVHGT'],
      8'6':['Mean Period of Wind Waves','s','WVPER'],
      9'7':['Direction of Swell Waves','degree true','SWDIR'],
     10'8':['Significant Height of Swell Waves','m','SWELL'],
     11'9':['Mean Period of Swell Waves','s','SWPER'],
     12'10':['Primary Wave Direction','degree true','DIRPW'],
     13'11':['Primary Wave Mean Period','s','PERPW'],
     14'12':['Secondary Wave Direction','degree true','DIRSW'],
     15'13':['Secondary Wave Mean Period','s','PERSW'],
     16'14':['Direction of Combined Wind Waves and Swell','degree true','WWSDIR'],
     17'15':['Mean Period of Combined Wind Waves and Swell','s','MWSPER'],
     18'16':['Coefficient of Drag With Waves','-','CDWW'],
     19'17':['Friction Velocity','m s-1','FRICVW'],
     20'18':['Wave Stress','N m-2','WSTR'],
     21'19':['Normalised Waves Stress','-','NWSTR'],
     22'20':['Mean Square Slope of Waves','-','MSSW'],
     23'21':['U-component Surface Stokes Drift','m s-1','USSD'],
     24'22':['V-component Surface Stokes Drift','m s-1','VSSD'],
     25'23':['Period of Maximum Individual Wave Height','s','PMAXWH'],
     26'24':['Maximum Individual Wave Height','m','MAXWH'],
     27'25':['Inverse Mean Wave Frequency','s','IMWF'],
     28'26':['Inverse Mean Frequency of The Wind Waves','s','IMFWW'],
     29'27':['Inverse Mean Frequency of The Total Swell','s','IMFTSW'],
     30'28':['Mean Zero-Crossing Wave Period','s','MZWPER'],
     31'29':['Mean Zero-Crossing Period of The Wind Waves','s','MZPWW'],
     32'30':['Mean Zero-Crossing Period of The Total Swell','s','MZPTSW'],
     33'31':['Wave Directional Width','-','WDIRW'],
     34'32':['Directional Width of The Wind Waves','-','DIRWWW'],
     35'33':['Directional Width of The Total Swell','-','DIRWTS'],
     36'34':['Peak Wave Period','s','PWPER'],
     37'35':['Peak Period of The Wind Waves','s','PPERWW'],
     38'36':['Peak Period of The Total Swell','s','PPERTS'],
     39'37':['Altimeter Wave Height','m','ALTWH'],
     40'38':['Altimeter Corrected Wave Height','m','ALCWH'],
     41'39':['Altimeter Range Relative Correction','-','ALRRC'],
     42'40':['10 Metre Neutral Wind Speed Over Waves','m s-1','MNWSOW'],
     43'41':['10 Metre Wind Direction Over Waves','degree true','MWDIRW'],
     44'42':['Wave Engery Spectrum','m-2 s rad-1','WESP'],
     45'43':['Kurtosis of The Sea Surface Elevation Due to Waves','-','KSSEW'],
     46'44':['Benjamin-Feir Index','-','BENINX'],
     47'45':['Spectral Peakedness Factor','s-1','SPFTR'],
     48'46':['Peak wave direction','&deg','PWAVEDIR'],
     49'47':['Significant wave height of first swell partition','m','SWHFSWEL'],
     50'48':['Significant wave height of second swell partition','m','SWHSSWEL'],
     51'49':['Significant wave height of third swell partition','m','SWHTSWEL'],
     52'50':['Mean wave period of first swell partition','s','MWPFSWEL'],
     53'51':['Mean wave period of second swell partition','s','MWPSSWEL'],
     54'52':['Mean wave period of third swell partition','s','MWPTSWEL'],
     55'53':['Mean wave direction of first swell partition','&deg','MWDFSWEL'],
     56'54':['Mean wave direction of second swell partition','&deg','MWDSSWEL'],
     57'55':['Mean wave direction of third swell partition','&deg','MWDTSWEL'],
     58'56':['Wave directional width of first swell partition','-','WDWFSWEL'],
     59'57':['Wave directional width of second swell partition','-','WDWSSWEL'],
     60'58':['Wave directional width of third swell partition','-','WDWTSWEL'],
     61'59':['Wave frequency width of first swell partition','-','WFWFSWEL'],
     62'60':['Wave frequency width of second swell partition','-','WFWSSWEL'],
     63'61':['Wave frequency width of third swell partition','-','WFWTSWEL'],
     64'62':['Wave frequency width','-','WAVEFREW'],
     65'63':['Frequency width of wind waves','-','FREWWW'],
     66'64':['Frequency width of total swell','-','FREWTSW'],
     67'65':['Peak Wave Period of First Swell Partition','s','PWPFSPAR'],
     68'66':['Peak Wave Period of Second Swell Partition','s','PWPSSPAR'],
     69'67':['Peak Wave Period of Third Swell Partition','s','PWPTSPAR'],
     70'68':['Peak Wave Direction of First Swell Partition','degree true','PWDFSPAR'],
     71'69':['Peak Wave Direction of Second Swell Partition','degree true','PWDSSPAR'],
     72'70':['Peak Wave Direction of Third Swell Partition','degree true','PWDTSPAR'],
     73'71':['Peak Direction of Wind Waves','degree true','PDWWAVE'],
     74'72':['Peak Direction of Total Swell','degree true','PDTSWELL'],
     75'73':['Whitecap Fraction','fraction','WCAPFRAC'],
     76'74':['Mean Direction of Total Swell','degree','MDTSWEL'],
     77'75':['Mean Direction of Wind Waves','degree','MDWWAVE'],
     78'76':['Charnock','Numeric','CHNCK'],
     79'77':['Wave Spectral Skewness','Numeric','WAVESPSK'],
     80'78':['Wave Energy Flux Magnitude','W m-1','WAVEFMAG'],
     81'79':['Wave Energy Flux Mean Direction','degree true','WAVEFDIR'],
     82'80':['Raio of Wave Angular and Frequency width','Numeric','RWAVEAFW'],
     83'81':['Free Convective Velocity over the Oceans','m s-1','FCVOCEAN'],
     84'82':['Air Density over the Oceans','kg m-3','AIRDENOC'],
     85'83':['Normalized Energy Flux into Waves','Numeric','NEFW'],
     86'84':['Normalized Stress into Ocean','Numeric','NSOCEAN'],
     87'85':['Normalized Energy Flux into Ocean','Numeric','NEFOCEAN'],
     88'86':['Surface Elevation Variance due to Waves (over all frequencies and directions)','m2 s rad-1','SEVWAVE'],
     89'87':['Wave Induced Mean Se Level Correction','m','WAVEMSLC'],
     90'88':['Spectral Width Index','Numeric','SPECWI'],
     91'89':['Number of Events in Freak Wave Statistics','Numeric','EFWS'],
     92'90':['U-Component of Surface Momentum Flux into Ocean','N m-2','USMFO'],
     93'91':['U-Component of Surface Momentum Flux into Ocean','N m-2','VSMFO'],
     94'92':['Wave Turbulent Energy Flux into Ocean','W m-2','WAVETEFO'],
     95'93':['Envelop maximum individual wave height','m','EMIWAVE'],
     96'94':['Time domain maximum individual crest height','m','TDMCREST'],
     97'95':['Time domain maximum individual wave height','m','TDMWAVE'],
     98'96':['Space time maximum individual crest height','m','STMCREST'],
     99'97':['Space time maximum individual wave height','m','STMWAVE'],
    100'98':['Goda peakedness factor','Numeric','GODAPEAK'],
    101'99-191':['Reserved','unknown','unknown'],
    102'192-254':['Reserved for Local Use','unknown','unknown'],
    103'192':['Wave Steepness','proportion','WSTP'],
    104'193':['Wave Length','unknown','WLENG'],
    105'255':['Missing','unknown','unknown'],
    106}
    107table_4_2_10_1  = {
    108'0':['Current Direction','degree True','DIRC'],
    109'1':['Current Speed','m s-1','SPC'],
    110'2':['U-Component of Current','m s-1','UOGRD'],
    111'3':['V-Component of Current','m s-1','VOGRD'],
    112'4':['Rip Current Occurrence Probability','%','RIPCOP'],
    113'5':['Eastward Current','m s-1','EASTCUR'],
    114'6':['Northward Current','m s-1','NRTHCUR'],
    115'7-191':['Reserved','unknown','unknown'],
    116'192-254':['Reserved for Local Use','unknown','unknown'],
    117'192':['Ocean Mixed Layer U Velocity','m s-1','OMLU'],
    118'193':['Ocean Mixed Layer V Velocity','m s-1','OMLV'],
    119'194':['Barotropic U velocity','m s-1','UBARO'],
    120'195':['Barotropic V velocity','m s-1','VBARO'],
    121'255':['Missing','unknown','unknown'],
    122}
    123table_4_2_10_2  = {
    124'0':['Ice Cover','Proportion','ICEC'],
    125'1':['Ice Thickness','m','ICETK'],
    126'2':['Direction of Ice Drift','degree True','DICED'],
    127'3':['Speed of Ice Drift','m s-1','SICED'],
    128'4':['U-Component of Ice Drift','m s-1','UICE'],
    129'5':['V-Component of Ice Drift','m s-1','VICE'],
    130'6':['Ice Growth Rate','m s-1','ICEG'],
    131'7':['Ice Divergence','s-1','ICED'],
    132'8':['Ice Temperature','K','ICETMP'],
    133'9':['Module of Ice Internal Pressure','Pa m','ICEPRS'],
    134'10':['Zonal Vector Component of Vertically Integrated Ice Internal Pressure','Pa m','ZVCICEP'],
    135'11':['Meridional Vector Component of Vertically Integrated Ice Internal Pressure','Pa m','MVCICEP'],
    136'12':['Compressive Ice Strength','N m-1','CICES'],
    137'13':['Snow Temperature (over sea ice)','K','SNOWTSI'],
    138'14':['Albedo','Numeric','ALBDOICE'],
    139'15':['Sea Ice Volume per Unit Area','m3m-2','SICEVOL'],
    140'16':['Snow Volume Over Sea Ice per Unit Area','m3m-2','SNVOLSI'],
    141'17':['Sea Ice Heat Content','J m-2','SICEHC'],
    142'18':['Snow over Sea Ice Heat Content','J m-2','SNCEHC'],
    143'19':['Ice Freeboard Thickness','m','ICEFTHCK'],
    144'20':['Ice Melt Pond Fraction','fraction','ICEMPF'],
    145'21':['Ice Melt Pond Depth','m','ICEMPD'],
    146'22':['Ice Melt Pond Volume per Unit Area','m3m-2','ICEMPV'],
    147'23':['Sea Ice Fraction Tendency due to Parameterization','s-1','SIFTP'],
    148'24':['x-component of ice drift','m s-1','XICE'],
    149'25':['y-component of ice drift','m s-1','YICE'],
    150'26':['Reserved','unknown','unknown'],
    151'27':['Freezing/melting potential (Tentatively accepted)','W m-2','FRZMLTPOT'],
    152'28':['Melt onset date (Tentatively accepted)','Numeric','MLTDATE'],
    153'29':['Freeze onset date (Tentatively accepted)','Numeric','FRZDATE'],
    154'30-191':['Reserved','unknown','unknown'],
    155'192-254':['Reserved for Local Use','unknown','unknown'],
    156'255':['Missing','unknown','unknown'],
    157}
    158table_4_2_10_3  = {
    159'0':['Water Temperature','K','WTMP'],
    160'1':['Deviation of Sea Level from Mean','m','DSLM'],
    161'2':['Heat Exchange Coefficient','unknown','CH'],
    162'3':['Practical Salinity','Numeric','PRACTSAL'],
    163'4':['Downward Heat Flux','W m-2','DWHFLUX'],
    164'5':['Eastward Surface Stress','N m-2','EASTWSS'],
    165'6':['Northward surface stress','N m-2','NORTHWSS'],
    166'7':['x-component Surface Stress','N m-2','XCOMPSS'],
    167'8':['y-component Surface Stress','N m-2','YCOMPSS'],
    168'9':['Thermosteric Change in Sea Surface Height','m','THERCSSH'],
    169'10':['Halosteric Change in Sea Surface Height','m','HALOCSSH'],
    170'11':['Steric Change in Sea Surface Height','m','STERCSSH'],
    171'12':['Sea Salt Flux','kg m-2s-1','SEASFLUX'],
    172'13':['Net upward water flux','kg m-2s-1','NETUPWFLUX'],
    173'14':['Eastward surface water velocity','m s-1','ESURFWVEL'],
    174'15':['Northward surface water velocity','m s-1','NSURFWVEL'],
    175'16':['x-component of surface water velocity','m s-1','XSURFWVEL'],
    176'17':['y-component of surface water velocity','m s-1','YSURFWVEL'],
    177'18':['Heat flux correction','W m-2','HFLUXCOR'],
    178'19':['Sea surface height tendency due to parameterization','m s-1','SSHGTPARM'],
    179'20':['Deviation of sea level from mean with inverse barometer correction','m','DSLIBARCOR'],
    180'21':['Salinity','kg kg-1','SALINITY'],
    181'22-191':['Reserved','unknown','unknown'],
    182'192-254':['Reserved for Local Use','unknown','unknown'],
    183'192':['Hurricane Storm Surge','m','SURGE'],
    184'193':['Extra Tropical Storm Surge','m','ETSRG'],
    185'194':['Ocean Surface Elevation Relative to Geoid','m','ELEV'],
    186'195':['Sea Surface Height Relative to Geoid','m','SSHG'],
    187'196':['Ocean Mixed Layer Potential Density (Reference 2000m)','kg m-3','P2OMLT'],
    188'197':['Net Air-Ocean Heat Flux','W m-2','AOHFLX'],
    189'198':['Assimilative Heat Flux','W m-2','ASHFL'],
    190'199':['Surface Temperature Trend','degree per day','SSTT'],
    191'200':['Surface Salinity Trend','psu per day','SSST'],
    192'201':['Kinetic Energy','J kg-1','KENG'],
    193'202':['Salt Flux','kg m-2s-1','SLTFL'],
    194'203':['Heat Exchange Coefficient','unknown','LCH'],
    195'204':['Freezing Spray','unknown','FRZSPR'],
    196'205':['Total Water Level Accounting for Tide, Wind and Waves','m','TWLWAV'],
    197'206':['Total Water Level Increase due to Waves','m','RUNUP'],
    198'207':['Mean Increase in Water Level due to Waves','m','SETUP'],
    199'208':['Time-varying Increase in Water Level due to Waves','m','SWASH'],
    200'209':['Total Water Level Above Dune Toe','m','TWLDT'],
    201'210':['Total Water Level Above Dune Crest','m','TWLDC'],
    202'211-241':['Reserved','unknown','unknown'],
    203'242':['20% Tropical Cyclone Storm Surge Exceedance','m','TCSRG20'],
    204'243':['30% Tropical Cyclone Storm Surge Exceedance','m','TCSRG30'],
    205'244':['40% Tropical Cyclone Storm Surge Exceedance','m','TCSRG40'],
    206'245':['50% Tropical Cyclone Storm Surge Exceedance','m','TCSRG50'],
    207'246':['60% Tropical Cyclone Storm Surge Exceedance','m','TCSRG60'],
    208'247':['70% Tropical Cyclone Storm Surge Exceedance','m','TCSRG70'],
    209'248':['80% Tropical Cyclone Storm Surge Exceedance','m','TCSRG80'],
    210'249':['90% Tropical Cyclone Storm Surge Exceedance','m','TCSRG90'],
    211'250':['Extra Tropical Storm Surge Combined Surge and Tide','m','ETCWL'],
    212'251':['Tide','m','TIDE'],
    213'252':['Erosion Occurrence Probability','%','EROSNP'],
    214'253':['Overwash Occurrence Probability','%','OWASHP'],
    215'254':['Reserved','unknown','unknown'],
    216'255':['Missing','unknown','unknown'],
    217}
    218table_4_2_10_4  = {
    219'0':['Main Thermocline Depth','m','MTHD'],
    220'1':['Main Thermocline Anomaly','m','MTHA'],
    221'2':['Transient Thermocline Depth','m','TTHDP'],
    222'3':['Salinity','kg kg-1','SALTY'],
    223'4':['Ocean Vertical Heat Diffusivity','m2 s-1','OVHD'],
    224'5':['Ocean Vertical Salt Diffusivity','m2 s-1','OVSD'],
    225'6':['Ocean Vertical Momentum Diffusivity','m2 s-1','OVMD'],
    226'7':['Bathymetry','m','BATHY'],
    227'8-10':['Reserved','unknown','unknown'],
    228'11':['Shape Factor With Respect To Salinity Profile','unknown','SFSALP'],
    229'12':['Shape Factor With Respect To Temperature Profile In Thermocline','unknown','SFTMPP'],
    230'13':['Attenuation Coefficient Of Water With Respect to Solar Radiation','m-1','ACWSRD'],
    231'14':['Water Depth','m','WDEPTH'],
    232'15':['Water Temperature','K','WTMPSS'],
    233'16':['Water Density (rho)','kg m-3','WATERDEN'],
    234'17':['Water Density Anomaly (sigma)','kg m-3','WATDENA'],
    235'18':['Water potential temperature (theta)','K','WATPTEMP'],
    236'19':['Water potential density (rho theta)','kg m-3','WATPDEN'],
    237'20':['Water potential density anomaly (sigma theta)','kg m-3','WATPDENA'],
    238'21':['Practical Salinity','psu (numeric)','PRTSAL'],
    239'22':['Water Column-integrated Heat Content','J m-2','WCHEATC'],
    240'23':['Eastward Water Velocity','m s-1','EASTWVEL'],
    241'24':['Northward Water Velocity','m s-1','NRTHWVEL'],
    242'25':['X-Component Water Velocity','m s-1','XCOMPWV'],
    243'26':['Y-Component Water Velocity','m s-1','YCOMPWV'],
    244'27':['Upward Water Velocity','m s-1','UPWWVEL'],
    245'28':['Vertical Eddy Diffusivity','m2 s-1','VEDDYDIF'],
    246'29':['Bottom Pressure Equivalent Height','m','BPEH'],
    247'30':['Fresh Water Flux into Sea Water from Rivers','kg m-2s-1','FWFSW'],
    248'31':['Fresh Water Flux Correction','kg m-2s-1','FWFC'],
    249'32':['Virtual Salt Flux into Sea Water','g kg-1 m-2s-1','VSFSW'],
    250'33':['Virtual Salt Flux Correction','g kg -1 m-2s-1','VSFC'],
    251'34':['Sea Water Temperature Tendency due to Newtonian Relaxation','K s-1','SWTTNR'],
    252'35':['Sea Water Salinity Tendency due to Newtonian Relaxation','g kg -1s-1','SWSTNR'],
    253'36':['Sea Water Temperature Tendency due to Parameterization','K s-1','SWTTP'],
    254'37':['Sea Water Salinity Tendency due to Parameterization','g kg -1s-1','SWSTP'],
    255'38':['Eastward Sea Water Velocity Tendency Due To Parameterization','m s-2','ESWVP'],
    256'39':['Northward Sea Water Velocity Tendency Due To Parameterization','m s-2','NSWVP'],
    257'40':['Sea Water Temperature Tendency Due to Direct Bias Correction','K s-1','SWTTBC'],
    258'41':['Sea Water Salinity Tendency due to Direct Bias Correction','g kg -1s-1','SWSTBC'],
    259'42':['Sea water meridional volume transport','m 3 m -2 s -1','SEAMVT'],
    260'43':['Sea water zonal volume transport','m 3 m -2 s -1','SEAZVT'],
    261'44':['Sea water column integrated meridional volume transport','m 3 m -2 s -1','SEACMVT'],
    262'45':['Sea water column integrated zonal volume transport','m 3 m -2 s -1','SEACZVT'],
    263'46':['Sea water meridional mass transport','kg m -2 s -1','SEAMMT'],
    264'47':['Sea water zonal mass transport','kg m -2 s -1','SEAZMT'],
    265'48':['Sea water column integrated meridional mass transport','kg m -2 s -1','SEACMMT'],
    266'49':['Sea water column integrated zonal mass transport','kg m -2 s -1','SEACZMT'],
    267'50':['Sea water column integrated practical salinity','g kg-1 m','SEACPSALT'],
    268'51':['Sea water column integrated salinity','kg kg-1 m','SEACSALT'],
    269'52-191':['Reserved','unknown','unknown'],
    270'192-254':['Reserved for Local Use','unknown','unknown'],
    271'192':['3-D Temperature','° c','WTMPC'],
    272'193':['3-D Salinity','psu','SALIN'],
    273'194':['Barotropic Kinectic Energy','J kg-1','BKENG'],
    274'195':['Geometric Depth Below Sea Surface','m','DBSS'],
    275'196':['Interface Depths','m','INTFD'],
    276'197':['Ocean Heat Content','J m-2','OHC'],
    277'255':['Missing','unknown','unknown'],
    278}
    279table_4_2_10_191  = {
    280'0':['Seconds Prior To Initial Reference Time (Defined In Section 1)','s','IRTSEC'],
    281'1':['Meridional Overturning Stream Function','m3 s-1','MOSF'],
    282'2':['Reserved','unknown','unknown'],
    283'3':['Days Since Last Observation','d','DSLOBSO'],
    284'4':['Barotropic Stream Function','m3 s-1','BARDSF'],
    285'5-191':['Reserved','unknown','unknown'],
    286'192-254':['Reserved for Local Use','unknown','unknown'],
    287'255':['Missing','unknown','unknown'],
    288}

table_4_2_10_0 = {'0': ['Wave Spectra (1)', '-', 'WVSP1'], '1': ['Wave Spectra (2)', '-', 'WVSP2'], '2': ['Wave Spectra (3)', '-', 'WVSP3'], '3': ['Significant Height of Combined Wind Waves and Swell', 'm', 'HTSGW'], '4': ['Direction of Wind Waves', 'degree true', 'WVDIR'], '5': ['Significant Height of Wind Waves', 'm', 'WVHGT'], '6': ['Mean Period of Wind Waves', 's', 'WVPER'], '7': ['Direction of Swell Waves', 'degree true', 'SWDIR'], '8': ['Significant Height of Swell Waves', 'm', 'SWELL'], '9': ['Mean Period of Swell Waves', 's', 'SWPER'], '10': ['Primary Wave Direction', 'degree true', 'DIRPW'], '11': ['Primary Wave Mean Period', 's', 'PERPW'], '12': ['Secondary Wave Direction', 'degree true', 'DIRSW'], '13': ['Secondary Wave Mean Period', 's', 'PERSW'], '14': ['Direction of Combined Wind Waves and Swell', 'degree true', 'WWSDIR'], '15': ['Mean Period of Combined Wind Waves and Swell', 's', 'MWSPER'], '16': ['Coefficient of Drag With Waves', '-', 'CDWW'], '17': ['Friction Velocity', 'm s-1', 'FRICVW'], '18': ['Wave Stress', 'N m-2', 'WSTR'], '19': ['Normalised Waves Stress', '-', 'NWSTR'], '20': ['Mean Square Slope of Waves', '-', 'MSSW'], '21': ['U-component Surface Stokes Drift', 'm s-1', 'USSD'], '22': ['V-component Surface Stokes Drift', 'm s-1', 'VSSD'], '23': ['Period of Maximum Individual Wave Height', 's', 'PMAXWH'], '24': ['Maximum Individual Wave Height', 'm', 'MAXWH'], '25': ['Inverse Mean Wave Frequency', 's', 'IMWF'], '26': ['Inverse Mean Frequency of The Wind Waves', 's', 'IMFWW'], '27': ['Inverse Mean Frequency of The Total Swell', 's', 'IMFTSW'], '28': ['Mean Zero-Crossing Wave Period', 's', 'MZWPER'], '29': ['Mean Zero-Crossing Period of The Wind Waves', 's', 'MZPWW'], '30': ['Mean Zero-Crossing Period of The Total Swell', 's', 'MZPTSW'], '31': ['Wave Directional Width', '-', 'WDIRW'], '32': ['Directional Width of The Wind Waves', '-', 'DIRWWW'], '33': ['Directional Width of The Total Swell', '-', 'DIRWTS'], '34': ['Peak Wave Period', 's', 'PWPER'], '35': ['Peak Period of The Wind Waves', 's', 'PPERWW'], '36': ['Peak Period of The Total Swell', 's', 'PPERTS'], '37': ['Altimeter Wave Height', 'm', 'ALTWH'], '38': ['Altimeter Corrected Wave Height', 'm', 'ALCWH'], '39': ['Altimeter Range Relative Correction', '-', 'ALRRC'], '40': ['10 Metre Neutral Wind Speed Over Waves', 'm s-1', 'MNWSOW'], '41': ['10 Metre Wind Direction Over Waves', 'degree true', 'MWDIRW'], '42': ['Wave Engery Spectrum', 'm-2 s rad-1', 'WESP'], '43': ['Kurtosis of The Sea Surface Elevation Due to Waves', '-', 'KSSEW'], '44': ['Benjamin-Feir Index', '-', 'BENINX'], '45': ['Spectral Peakedness Factor', 's-1', 'SPFTR'], '46': ['Peak wave direction', '&deg', 'PWAVEDIR'], '47': ['Significant wave height of first swell partition', 'm', 'SWHFSWEL'], '48': ['Significant wave height of second swell partition', 'm', 'SWHSSWEL'], '49': ['Significant wave height of third swell partition', 'm', 'SWHTSWEL'], '50': ['Mean wave period of first swell partition', 's', 'MWPFSWEL'], '51': ['Mean wave period of second swell partition', 's', 'MWPSSWEL'], '52': ['Mean wave period of third swell partition', 's', 'MWPTSWEL'], '53': ['Mean wave direction of first swell partition', '&deg', 'MWDFSWEL'], '54': ['Mean wave direction of second swell partition', '&deg', 'MWDSSWEL'], '55': ['Mean wave direction of third swell partition', '&deg', 'MWDTSWEL'], '56': ['Wave directional width of first swell partition', '-', 'WDWFSWEL'], '57': ['Wave directional width of second swell partition', '-', 'WDWSSWEL'], '58': ['Wave directional width of third swell partition', '-', 'WDWTSWEL'], '59': ['Wave frequency width of first swell partition', '-', 'WFWFSWEL'], '60': ['Wave frequency width of second swell partition', '-', 'WFWSSWEL'], '61': ['Wave frequency width of third swell partition', '-', 'WFWTSWEL'], '62': ['Wave frequency width', '-', 'WAVEFREW'], '63': ['Frequency width of wind waves', '-', 'FREWWW'], '64': ['Frequency width of total swell', '-', 'FREWTSW'], '65': ['Peak Wave Period of First Swell Partition', 's', 'PWPFSPAR'], '66': ['Peak Wave Period of Second Swell Partition', 's', 'PWPSSPAR'], '67': ['Peak Wave Period of Third Swell Partition', 's', 'PWPTSPAR'], '68': ['Peak Wave Direction of First Swell Partition', 'degree true', 'PWDFSPAR'], '69': ['Peak Wave Direction of Second Swell Partition', 'degree true', 'PWDSSPAR'], '70': ['Peak Wave Direction of Third Swell Partition', 'degree true', 'PWDTSPAR'], '71': ['Peak Direction of Wind Waves', 'degree true', 'PDWWAVE'], '72': ['Peak Direction of Total Swell', 'degree true', 'PDTSWELL'], '73': ['Whitecap Fraction', 'fraction', 'WCAPFRAC'], '74': ['Mean Direction of Total Swell', 'degree', 'MDTSWEL'], '75': ['Mean Direction of Wind Waves', 'degree', 'MDWWAVE'], '76': ['Charnock', 'Numeric', 'CHNCK'], '77': ['Wave Spectral Skewness', 'Numeric', 'WAVESPSK'], '78': ['Wave Energy Flux Magnitude', 'W m-1', 'WAVEFMAG'], '79': ['Wave Energy Flux Mean Direction', 'degree true', 'WAVEFDIR'], '80': ['Raio of Wave Angular and Frequency width', 'Numeric', 'RWAVEAFW'], '81': ['Free Convective Velocity over the Oceans', 'm s-1', 'FCVOCEAN'], '82': ['Air Density over the Oceans', 'kg m-3', 'AIRDENOC'], '83': ['Normalized Energy Flux into Waves', 'Numeric', 'NEFW'], '84': ['Normalized Stress into Ocean', 'Numeric', 'NSOCEAN'], '85': ['Normalized Energy Flux into Ocean', 'Numeric', 'NEFOCEAN'], '86': ['Surface Elevation Variance due to Waves (over all frequencies and directions)', 'm2 s rad-1', 'SEVWAVE'], '87': ['Wave Induced Mean Se Level Correction', 'm', 'WAVEMSLC'], '88': ['Spectral Width Index', 'Numeric', 'SPECWI'], '89': ['Number of Events in Freak Wave Statistics', 'Numeric', 'EFWS'], '90': ['U-Component of Surface Momentum Flux into Ocean', 'N m-2', 'USMFO'], '91': ['U-Component of Surface Momentum Flux into Ocean', 'N m-2', 'VSMFO'], '92': ['Wave Turbulent Energy Flux into Ocean', 'W m-2', 'WAVETEFO'], '93': ['Envelop maximum individual wave height', 'm', 'EMIWAVE'], '94': ['Time domain maximum individual crest height', 'm', 'TDMCREST'], '95': ['Time domain maximum individual wave height', 'm', 'TDMWAVE'], '96': ['Space time maximum individual crest height', 'm', 'STMCREST'], '97': ['Space time maximum individual wave height', 'm', 'STMWAVE'], '98': ['Goda peakedness factor', 'Numeric', 'GODAPEAK'], '99-191': ['Reserved', 'unknown', 'unknown'], '192-254': ['Reserved for Local Use', 'unknown', 'unknown'], '192': ['Wave Steepness', 'proportion', 'WSTP'], '193': ['Wave Length', 'unknown', 'WLENG'], '255': ['Missing', 'unknown', 'unknown']}
table_4_2_10_1 = {'0': ['Current Direction', 'degree True', 'DIRC'], '1': ['Current Speed', 'm s-1', 'SPC'], '2': ['U-Component of Current', 'm s-1', 'UOGRD'], '3': ['V-Component of Current', 'm s-1', 'VOGRD'], '4': ['Rip Current Occurrence Probability', '%', 'RIPCOP'], '5': ['Eastward Current', 'm s-1', 'EASTCUR'], '6': ['Northward Current', 'm s-1', 'NRTHCUR'], '7-191': ['Reserved', 'unknown', 'unknown'], '192-254': ['Reserved for Local Use', 'unknown', 'unknown'], '192': ['Ocean Mixed Layer U Velocity', 'm s-1', 'OMLU'], '193': ['Ocean Mixed Layer V Velocity', 'm s-1', 'OMLV'], '194': ['Barotropic U velocity', 'm s-1', 'UBARO'], '195': ['Barotropic V velocity', 'm s-1', 'VBARO'], '255': ['Missing', 'unknown', 'unknown']}
table_4_2_10_2 = {'0': ['Ice Cover', 'Proportion', 'ICEC'], '1': ['Ice Thickness', 'm', 'ICETK'], '2': ['Direction of Ice Drift', 'degree True', 'DICED'], '3': ['Speed of Ice Drift', 'm s-1', 'SICED'], '4': ['U-Component of Ice Drift', 'm s-1', 'UICE'], '5': ['V-Component of Ice Drift', 'm s-1', 'VICE'], '6': ['Ice Growth Rate', 'm s-1', 'ICEG'], '7': ['Ice Divergence', 's-1', 'ICED'], '8': ['Ice Temperature', 'K', 'ICETMP'], '9': ['Module of Ice Internal Pressure', 'Pa m', 'ICEPRS'], '10': ['Zonal Vector Component of Vertically Integrated Ice Internal Pressure', 'Pa m', 'ZVCICEP'], '11': ['Meridional Vector Component of Vertically Integrated Ice Internal Pressure', 'Pa m', 'MVCICEP'], '12': ['Compressive Ice Strength', 'N m-1', 'CICES'], '13': ['Snow Temperature (over sea ice)', 'K', 'SNOWTSI'], '14': ['Albedo', 'Numeric', 'ALBDOICE'], '15': ['Sea Ice Volume per Unit Area', 'm3m-2', 'SICEVOL'], '16': ['Snow Volume Over Sea Ice per Unit Area', 'm3m-2', 'SNVOLSI'], '17': ['Sea Ice Heat Content', 'J m-2', 'SICEHC'], '18': ['Snow over Sea Ice Heat Content', 'J m-2', 'SNCEHC'], '19': ['Ice Freeboard Thickness', 'm', 'ICEFTHCK'], '20': ['Ice Melt Pond Fraction', 'fraction', 'ICEMPF'], '21': ['Ice Melt Pond Depth', 'm', 'ICEMPD'], '22': ['Ice Melt Pond Volume per Unit Area', 'm3m-2', 'ICEMPV'], '23': ['Sea Ice Fraction Tendency due to Parameterization', 's-1', 'SIFTP'], '24': ['x-component of ice drift', 'm s-1', 'XICE'], '25': ['y-component of ice drift', 'm s-1', 'YICE'], '26': ['Reserved', 'unknown', 'unknown'], '27': ['Freezing/melting potential (Tentatively accepted)', 'W m-2', 'FRZMLTPOT'], '28': ['Melt onset date (Tentatively accepted)', 'Numeric', 'MLTDATE'], '29': ['Freeze onset date (Tentatively accepted)', 'Numeric', 'FRZDATE'], '30-191': ['Reserved', 'unknown', 'unknown'], '192-254': ['Reserved for Local Use', 'unknown', 'unknown'], '255': ['Missing', 'unknown', 'unknown']}
table_4_2_10_3 = {'0': ['Water Temperature', 'K', 'WTMP'], '1': ['Deviation of Sea Level from Mean', 'm', 'DSLM'], '2': ['Heat Exchange Coefficient', 'unknown', 'CH'], '3': ['Practical Salinity', 'Numeric', 'PRACTSAL'], '4': ['Downward Heat Flux', 'W m-2', 'DWHFLUX'], '5': ['Eastward Surface Stress', 'N m-2', 'EASTWSS'], '6': ['Northward surface stress', 'N m-2', 'NORTHWSS'], '7': ['x-component Surface Stress', 'N m-2', 'XCOMPSS'], '8': ['y-component Surface Stress', 'N m-2', 'YCOMPSS'], '9': ['Thermosteric Change in Sea Surface Height', 'm', 'THERCSSH'], '10': ['Halosteric Change in Sea Surface Height', 'm', 'HALOCSSH'], '11': ['Steric Change in Sea Surface Height', 'm', 'STERCSSH'], '12': ['Sea Salt Flux', 'kg m-2s-1', 'SEASFLUX'], '13': ['Net upward water flux', 'kg m-2s-1', 'NETUPWFLUX'], '14': ['Eastward surface water velocity', 'm s-1', 'ESURFWVEL'], '15': ['Northward surface water velocity', 'm s-1', 'NSURFWVEL'], '16': ['x-component of surface water velocity', 'm s-1', 'XSURFWVEL'], '17': ['y-component of surface water velocity', 'm s-1', 'YSURFWVEL'], '18': ['Heat flux correction', 'W m-2', 'HFLUXCOR'], '19': ['Sea surface height tendency due to parameterization', 'm s-1', 'SSHGTPARM'], '20': ['Deviation of sea level from mean with inverse barometer correction', 'm', 'DSLIBARCOR'], '21': ['Salinity', 'kg kg-1', 'SALINITY'], '22-191': ['Reserved', 'unknown', 'unknown'], '192-254': ['Reserved for Local Use', 'unknown', 'unknown'], '192': ['Hurricane Storm Surge', 'm', 'SURGE'], '193': ['Extra Tropical Storm Surge', 'm', 'ETSRG'], '194': ['Ocean Surface Elevation Relative to Geoid', 'm', 'ELEV'], '195': ['Sea Surface Height Relative to Geoid', 'm', 'SSHG'], '196': ['Ocean Mixed Layer Potential Density (Reference 2000m)', 'kg m-3', 'P2OMLT'], '197': ['Net Air-Ocean Heat Flux', 'W m-2', 'AOHFLX'], '198': ['Assimilative Heat Flux', 'W m-2', 'ASHFL'], '199': ['Surface Temperature Trend', 'degree per day', 'SSTT'], '200': ['Surface Salinity Trend', 'psu per day', 'SSST'], '201': ['Kinetic Energy', 'J kg-1', 'KENG'], '202': ['Salt Flux', 'kg m-2s-1', 'SLTFL'], '203': ['Heat Exchange Coefficient', 'unknown', 'LCH'], '204': ['Freezing Spray', 'unknown', 'FRZSPR'], '205': ['Total Water Level Accounting for Tide, Wind and Waves', 'm', 'TWLWAV'], '206': ['Total Water Level Increase due to Waves', 'm', 'RUNUP'], '207': ['Mean Increase in Water Level due to Waves', 'm', 'SETUP'], '208': ['Time-varying Increase in Water Level due to Waves', 'm', 'SWASH'], '209': ['Total Water Level Above Dune Toe', 'm', 'TWLDT'], '210': ['Total Water Level Above Dune Crest', 'm', 'TWLDC'], '211-241': ['Reserved', 'unknown', 'unknown'], '242': ['20% Tropical Cyclone Storm Surge Exceedance', 'm', 'TCSRG20'], '243': ['30% Tropical Cyclone Storm Surge Exceedance', 'm', 'TCSRG30'], '244': ['40% Tropical Cyclone Storm Surge Exceedance', 'm', 'TCSRG40'], '245': ['50% Tropical Cyclone Storm Surge Exceedance', 'm', 'TCSRG50'], '246': ['60% Tropical Cyclone Storm Surge Exceedance', 'm', 'TCSRG60'], '247': ['70% Tropical Cyclone Storm Surge Exceedance', 'm', 'TCSRG70'], '248': ['80% Tropical Cyclone Storm Surge Exceedance', 'm', 'TCSRG80'], '249': ['90% Tropical Cyclone Storm Surge Exceedance', 'm', 'TCSRG90'], '250': ['Extra Tropical Storm Surge Combined Surge and Tide', 'm', 'ETCWL'], '251': ['Tide', 'm', 'TIDE'], '252': ['Erosion Occurrence Probability', '%', 'EROSNP'], '253': ['Overwash Occurrence Probability', '%', 'OWASHP'], '254': ['Reserved', 'unknown', 'unknown'], '255': ['Missing', 'unknown', 'unknown']}
table_4_2_10_4 = {'0': ['Main Thermocline Depth', 'm', 'MTHD'], '1': ['Main Thermocline Anomaly', 'm', 'MTHA'], '2': ['Transient Thermocline Depth', 'm', 'TTHDP'], '3': ['Salinity', 'kg kg-1', 'SALTY'], '4': ['Ocean Vertical Heat Diffusivity', 'm2 s-1', 'OVHD'], '5': ['Ocean Vertical Salt Diffusivity', 'm2 s-1', 'OVSD'], '6': ['Ocean Vertical Momentum Diffusivity', 'm2 s-1', 'OVMD'], '7': ['Bathymetry', 'm', 'BATHY'], '8-10': ['Reserved', 'unknown', 'unknown'], '11': ['Shape Factor With Respect To Salinity Profile', 'unknown', 'SFSALP'], '12': ['Shape Factor With Respect To Temperature Profile In Thermocline', 'unknown', 'SFTMPP'], '13': ['Attenuation Coefficient Of Water With Respect to Solar Radiation', 'm-1', 'ACWSRD'], '14': ['Water Depth', 'm', 'WDEPTH'], '15': ['Water Temperature', 'K', 'WTMPSS'], '16': ['Water Density (rho)', 'kg m-3', 'WATERDEN'], '17': ['Water Density Anomaly (sigma)', 'kg m-3', 'WATDENA'], '18': ['Water potential temperature (theta)', 'K', 'WATPTEMP'], '19': ['Water potential density (rho theta)', 'kg m-3', 'WATPDEN'], '20': ['Water potential density anomaly (sigma theta)', 'kg m-3', 'WATPDENA'], '21': ['Practical Salinity', 'psu (numeric)', 'PRTSAL'], '22': ['Water Column-integrated Heat Content', 'J m-2', 'WCHEATC'], '23': ['Eastward Water Velocity', 'm s-1', 'EASTWVEL'], '24': ['Northward Water Velocity', 'm s-1', 'NRTHWVEL'], '25': ['X-Component Water Velocity', 'm s-1', 'XCOMPWV'], '26': ['Y-Component Water Velocity', 'm s-1', 'YCOMPWV'], '27': ['Upward Water Velocity', 'm s-1', 'UPWWVEL'], '28': ['Vertical Eddy Diffusivity', 'm2 s-1', 'VEDDYDIF'], '29': ['Bottom Pressure Equivalent Height', 'm', 'BPEH'], '30': ['Fresh Water Flux into Sea Water from Rivers', 'kg m-2s-1', 'FWFSW'], '31': ['Fresh Water Flux Correction', 'kg m-2s-1', 'FWFC'], '32': ['Virtual Salt Flux into Sea Water', 'g kg-1 m-2s-1', 'VSFSW'], '33': ['Virtual Salt Flux Correction', 'g kg -1 m-2s-1', 'VSFC'], '34': ['Sea Water Temperature Tendency due to Newtonian Relaxation', 'K s-1', 'SWTTNR'], '35': ['Sea Water Salinity Tendency due to Newtonian Relaxation', 'g kg -1s-1', 'SWSTNR'], '36': ['Sea Water Temperature Tendency due to Parameterization', 'K s-1', 'SWTTP'], '37': ['Sea Water Salinity Tendency due to Parameterization', 'g kg -1s-1', 'SWSTP'], '38': ['Eastward Sea Water Velocity Tendency Due To Parameterization', 'm s-2', 'ESWVP'], '39': ['Northward Sea Water Velocity Tendency Due To Parameterization', 'm s-2', 'NSWVP'], '40': ['Sea Water Temperature Tendency Due to Direct Bias Correction', 'K s-1', 'SWTTBC'], '41': ['Sea Water Salinity Tendency due to Direct Bias Correction', 'g kg -1s-1', 'SWSTBC'], '42': ['Sea water meridional volume transport', 'm 3 m -2 s -1', 'SEAMVT'], '43': ['Sea water zonal volume transport', 'm 3 m -2 s -1', 'SEAZVT'], '44': ['Sea water column integrated meridional volume transport', 'm 3 m -2 s -1', 'SEACMVT'], '45': ['Sea water column integrated zonal volume transport', 'm 3 m -2 s -1', 'SEACZVT'], '46': ['Sea water meridional mass transport', 'kg m -2 s -1', 'SEAMMT'], '47': ['Sea water zonal mass transport', 'kg m -2 s -1', 'SEAZMT'], '48': ['Sea water column integrated meridional mass transport', 'kg m -2 s -1', 'SEACMMT'], '49': ['Sea water column integrated zonal mass transport', 'kg m -2 s -1', 'SEACZMT'], '50': ['Sea water column integrated practical salinity', 'g kg-1 m', 'SEACPSALT'], '51': ['Sea water column integrated salinity', 'kg kg-1 m', 'SEACSALT'], '52-191': ['Reserved', 'unknown', 'unknown'], '192-254': ['Reserved for Local Use', 'unknown', 'unknown'], '192': ['3-D Temperature', '° c', 'WTMPC'], '193': ['3-D Salinity', 'psu', 'SALIN'], '194': ['Barotropic Kinectic Energy', 'J kg-1', 'BKENG'], '195': ['Geometric Depth Below Sea Surface', 'm', 'DBSS'], '196': ['Interface Depths', 'm', 'INTFD'], '197': ['Ocean Heat Content', 'J m-2', 'OHC'], '255': ['Missing', 'unknown', 'unknown']}
table_4_2_10_191 = {'0': ['Seconds Prior To Initial Reference Time (Defined In Section 1)', 's', 'IRTSEC'], '1': ['Meridional Overturning Stream Function', 'm3 s-1', 'MOSF'], '2': ['Reserved', 'unknown', 'unknown'], '3': ['Days Since Last Observation', 'd', 'DSLOBSO'], '4': ['Barotropic Stream Function', 'm3 s-1', 'BARDSF'], '5-191': ['Reserved', 'unknown', 'unknown'], '192-254': ['Reserved for Local Use', 'unknown', 'unknown'], '255': ['Missing', 'unknown', 'unknown']}